package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcLunbo;

/**
 * 轮播设置Service接口
 * 
 * @author hs
 * @date 2024-03-16
 */
public interface ISzxcLunboService 
{
    /**
     * 查询轮播设置
     * 
     * @param id 轮播设置主键
     * @return 轮播设置
     */
    public SzxcLunbo selectSzxcLunboById(Long id);

    /**
     * 查询轮播设置列表
     * 
     * @param szxcLunbo 轮播设置
     * @return 轮播设置集合
     */
    public List<SzxcLunbo> selectSzxcLunboList(SzxcLunbo szxcLunbo);

    /**
     * 新增轮播设置
     * 
     * @param szxcLunbo 轮播设置
     * @return 结果
     */
    public int insertSzxcLunbo(SzxcLunbo szxcLunbo);

    /**
     * 修改轮播设置
     * 
     * @param szxcLunbo 轮播设置
     * @return 结果
     */
    public int updateSzxcLunbo(SzxcLunbo szxcLunbo);

    /**
     * 批量删除轮播设置
     * 
     * @param ids 需要删除的轮播设置主键集合
     * @return 结果
     */
    public int deleteSzxcLunboByIds(Long[] ids);

    /**
     * 删除轮播设置信息
     * 
     * @param id 轮播设置主键
     * @return 结果
     */
    public int deleteSzxcLunboById(Long id);
}
